@@ -312,9 +312,9 @@ class R3sponse(object):
 		):
 
 			# check self instance.
-			if isinstance(attributes, ResponseObject):
+			if isinstance(attributes, R3sponse.ResponseObject):
 				attributes = attributes.dict()
-			if isinstance(json, ResponseObject):
+			if isinstance(json, R3sponse.ResponseObject):
 				json = json.dict()
 
 			# assign attributes.
@@ -330,7 +330,7 @@ class R3sponse(object):
 				elif isinstance(json, dict):
 					self.assign(json)
 				elif json != None:
-					raise ValueError("Invalid usage, the r3sponse.ResponseObject json parameter must be str / dict format.")
+					raise exceptions.InvalidUsage("The r3sponse.ResponseObject json parameter must be str / dict format.")
 			else:
 				self.assign(attributes)
 
